Module rdc_file

Module rdc_file 

Structs

RdcFrameCaptureChunks
Streaming iterator over frame-capture chunks from a .rdc file.

Enums

RdcDriver
Rendering API used in a .rdc capture file, corresponding to RenderDoc’s RDCDriver enum.

Functions

d3d11_swapchain_size_from_chunk
For a D3D11 CreateSwapBuffer chunk, returns (width, height) of the back buffer. Returns None for any other chunk type or truncated data.
parse_rdc_driver
Parse the rendering API from a RenderDoc .rdc capture file header.
parse_rdc_frame_capture_chunks
Seeks to the FrameCapture section in an .rdc reader and returns a chunk iterator. The reader must be positioned at the start of the file.