pub struct TraceDeviceEntry {
pub checksum: String,
pub singlethread: bool,
pub skip: bool,
pub replay_args: Vec<String>,
}Fields
checksum: Stringsinglethread: boolDon’t run any other traces in parallel with this one.
skip: boolSkip this trace on this device entirely.
replay_args: Vec<String>Extra arguments appended to the replay command for this trace on this device. Concatenated after any per-trace replay_args.