pub struct TracesConfig {
pub traces_db: TracesDb,
pub devices: HashMap<String, DeviceEntry>,
pub traces: Vec<TraceEntry>,
}Fields
traces_db: TracesDbdevices: HashMap<String, DeviceEntry>Per-device declarations (memory capacity, etc). Devices referenced by trace entries but not present here are treated as having zero capacity.
traces: Vec<TraceEntry>Implementations
Sourceimpl TracesConfig
impl TracesConfig
pub fn load(path: &Path) -> Result<TracesConfig>
Sourcepub fn active_for_device<'a>(
&'a self,
device: &'a str,
) -> impl Iterator<Item = (&'a TraceEntry, &'a TraceDeviceEntry)>
pub fn active_for_device<'a>( &'a self, device: &'a str, ) -> impl Iterator<Item = (&'a TraceEntry, &'a TraceDeviceEntry)>
Iterates over traces that have an entry for device and are not marked skip.