pub struct TraceEntry {
pub path: String,
pub nonloopable: bool,
pub replay_args: Vec<String>,
pub devices: HashMap<String, DeviceEntry>,
}Fields
path: Stringnonloopable: boolWhen true, we shouldn’t use apitrace’s internal frame looping support due to instability (not all sequences of API calls can just be replayed). Instead, do the replay as many times as we are capturing frames.
replay_args: Vec<String>Extra arguments appended to the replay command for this trace, regardless of device. Concatenated with any per-device replay_args.
devices: HashMap<String, DeviceEntry>Implementations
Sourceimpl TraceEntry
impl TraceEntry
pub fn device(&self, name: &str) -> Option<&DeviceEntry>